import { Camera } from './camera/camera';
import { Ray, Vector3 } from '@tinyjs-plugin-three/math';
import { Container3D } from './container';
export declare type Intersect = {
    point: Vector3;
    distance: number;
    bindObject: Container3D;
    interactObject: Container3D;
};
export declare type RayCastOption = {
    rayCaster: RayCaster;
    object: Container3D;
    accurate: boolean;
    recursive: boolean;
    intersects: Intersect[];
};
export declare class RayCaster {
    ray: Ray;
    near: number;
    far: number;
    camera: Camera;
    /**
     * RayCaster 构造函数
     * @param near rayCaster 的近距离投射点
     * @param far rayCaster 的远距离投射点
     */
    constructor(near?: number, far?: number, camera?: Camera);
    /**
     * 设置光线投射的 Ray
     * @param origin 光线投射的原点
     * @param direction 光线投射的方向
    */
    setRay(origin: number[] | Vector3, direction: number[] | Vector3): void;
    /**
     * 通过屏幕上的 [x,y] 坐标设置光线投射的 Ray
     * @param x x坐标
     * @param y y坐标
     * @param camera 相机
     */
    setRayFromScreen(x: number, y: number, camera?: Camera): void;
    /**
     * 判断光线是否和物体列表中的物体相交，返回相交节点对象
     * @param option 参数
     * @param option.objects 3D 物体列表
     * @param option.accurate 是否做精确计算（为 否时，只计算到 boundingBox）
     * @param option.recursive 是否遍历后代节点
     * @param option.intersects 相交物体的数组
     */
    intersectObjects({ objects, accurate, intersects, recursive }: {
        objects: Container3D[] | Container3D;
        accurate?: boolean;
        recursive?: boolean;
        intersects?: Intersect[];
    }): Intersect[];
}
