/**
 * Represents a specific interpolation method.
 */
export declare abstract class glTFInterpolation {
    /**
     * Interpolates within an animation frame and returns the output.
     * @param frame The animation frame to interpolate.
     * @param position The position within the animation frame (between 0-1).
     */
    abstract interpolate(frame: number, position: number): Float32Array;
    abstract get data(): Float32Array;
    abstract get output(): ArrayLike<number>;
    static from(type: string, input: ArrayLike<number>, output: ArrayLike<number>, stride: number): glTFLinear | glTFCubicSpline | glTFStep;
}
export declare class glTFLinear extends glTFInterpolation {
    private _output;
    private _stride;
    private _data;
    constructor(_output: ArrayLike<number>, _stride: number);
    interpolate(frame: number, position: number): Float32Array;
    get output(): ArrayLike<number>;
    get data(): Float32Array;
}
export declare class glTFCubicSpline extends glTFInterpolation {
    private _input;
    private _output;
    private _stride;
    private _data;
    constructor(_input: ArrayLike<number>, _output: ArrayLike<number>, _stride: number);
    interpolate(frame: number, position: number): Float32Array;
    static calculate(t: number, p0: number, p1: number, m0: number, m1: number): number;
    get data(): Float32Array;
    get output(): ArrayLike<number>;
}
export declare class glTFStep extends glTFInterpolation {
    private _output;
    private _stride;
    private _data;
    constructor(_output: ArrayLike<number>, _stride: number);
    get data(): Float32Array;
    get output(): ArrayLike<number>;
    interpolate(frame: number): Float32Array;
}
