import * as Tiny from '@alipay/tiny.js';
import { glTFExternalResourceLoader } from '../loader/gltf-loader';
/**
 * glTF assets are JSON files plus supporting external data.
 */
export declare class glTFAsset {
    private _buffers;
    private _images;
    private _descriptor;
    /**
     * Creates a new glTF asset using the specified JSON descriptor. The resources
     * (buffers and images) will not be loaded automatically.
     * @param descriptor The JSON descriptor to create the asset from.
     */
    constructor(descriptor: any);
    /** The images used by this asset. */
    get images(): Tiny.Texture<Tiny.Resource>[];
    /** The descriptor used by this asset. */
    get descriptor(): any;
    /** The buffers used by this asset. */
    get buffers(): ArrayBuffer[];
    /**
     * Loads a new glTF asset (including resources) using the specified JSON
     * descriptor.
     * @param descriptor The JSON descriptor to create the asset from.
     * @param loader The resource loader to use for external resources. The
     * loader can be empty when all resources in the descriptor is embedded.
     */
    static load(descriptor: any, loader?: glTFExternalResourceLoader): glTFAsset;
    /**
     * Returns a value indicating if the specified data buffer is a valid glTF.
     * @param data The buffer data to validate.
     */
    static isValid(data: ArrayBuffer): boolean;
    /**
   * Creates a new glTF asset from binary (glb) buffer data.
   * @param data The binary buffer data to read from.
   * @param callback The function which gets called when the asset has been
   * created.
   */
    static fromBuffer(data: ArrayBuffer): Promise<glTFAsset>;
    static isEmbeddedResource(uri: string): boolean;
    static getEmbeddedBuffer(value: string): ArrayBufferLike;
}
/**
 * Represents a loader for glTF asset resources (buffers and images).
 */
export interface glTFAssetResourceLoader {
    /**
     * Loads the resource from the specified uri.
     * @param uri The uri to load from.
     * @param onComplete Callback when loading is completed.
     * @param options Loader option
     */
    load(uri: string, onComplete: (resource: Tiny.LoaderResource) => void, options?: {
        loadType?: Tiny.LoaderResource.LOAD_TYPE;
        xhrType?: Tiny.LoaderResource.XHR_RESPONSE_TYPE;
        metadata?: {
            [key: string]: any;
        };
    }): void;
}
