import * as Tiny from '@alipay/tiny.js';
import { CubeMipmapTexture } from '../cubemap/cube-mipmap-texture';
/**
 * A collection of components used for image-based lighting (IBL).
 */
export declare class ImageBasedLighting {
    private _diffuse;
    private _brdf;
    private _specular;
    private _irradianceCoefficients;
    intensity: number;
    reflectionsIntensity: number;
    /** Cube texture used for the diffuse component. */
    get diffuse(): CubeMipmapTexture;
    /** BRDF integration map lookup texture. */
    get brdf(): Tiny.Texture<Tiny.Resource>;
    /** Cube mipmap texture used for the specular component. */
    get specular(): CubeMipmapTexture;
    get irradianceCoefficients(): number[];
    /**
     * Creates a new image-based lighting object.
     * @param diffuse Cube texture used for the diffuse component.
     * @param specular Cube mipmap texture used for the specular component.
     * @param brdf BRDF integration map lookup texture.
     */
    constructor({ specular, diffuse, brdf, irradianceCoefficients, intensity, reflectionsIntensity }: {
        specular: CubeMipmapTexture;
        diffuse?: CubeMipmapTexture;
        brdf?: Tiny.Texture;
        irradianceCoefficients?: number[];
        intensity?: number;
        reflectionsIntensity?: number;
    });
    /**
     * Value indicating if this object is valid to be used for rendering.
     */
    get valid(): boolean | number[];
}
