import * as Tiny from '@alipay/tiny.js';
import { StandardShader } from './standard-shader';
import { Material } from '../material';
import { LightingEnvironment } from '../../lighting/lighting-environment';
import { Mesh3D } from '../../mesh/mesh';
import { StandardMaterialAlphaMode } from './standard-material-alpha-mode';
import { StandardMaterialDebugMode } from './standard-material-debug-mode';
import { ShadowCastingLight } from '../../shadow/shadow-casting-light';
import { StandardMaterialSkinUniforms } from './standard-material-skin-uniforms';
import { InstancedStandardMaterial } from './instanced-standard-material';
/**
 * The standard material is using Physically-Based Rendering (PBR) which makes
 * it suitable to represent a wide range of different surfaces. It's the default
 * material when loading models from file.
 */
export declare class StandardMaterial extends Material {
    protected name?: string;
    private _lightingEnvironment?;
    private _unlit;
    private _alphaMode;
    private _debugMode?;
    private _baseColorTexture?;
    private _normalTexture?;
    private _occlusionTexture?;
    private _occlusionStrength?;
    private _emissiveTexture?;
    private _metallicRoughnessTexture?;
    private _shadowCastingLight?;
    private _lightsCount?;
    private _instancingEnabled;
    private _baseColor;
    private _useSpecularAA;
    private _skinUniforms;
    /** The roughness of the material. */
    roughness: number;
    /** The metalness of the material. */
    metallic: number;
    /** The base color of the material. Array containing RGBA values. */
    baseColor: number[];
    /** The cutoff threshold when alpha mode is set to "mask". */
    alphaCutoff: number;
    /** The emissive color of the material. Array containing RGB values. */
    emissive: number[];
    /** The exposure (brightness) of the material. */
    exposure: number;
    get skinUniforms(): StandardMaterialSkinUniforms;
    /** The base color texture. */
    get baseColorTexture(): Tiny.Texture | undefined;
    set baseColorTexture(value: Tiny.Texture | undefined);
    /** The metallic-roughness texture. */
    get metallicRoughnessTexture(): Tiny.Texture | undefined;
    set metallicRoughnessTexture(value: Tiny.Texture | undefined);
    /** The normal map texture. */
    get normalTexture(): Tiny.Texture | undefined;
    set normalTexture(value: Tiny.Texture | undefined);
    /** The occlusion map texture. */
    get occlusionTexture(): Tiny.Texture | undefined;
    set occlusionTexture(value: Tiny.Texture | undefined);
    /** The occlusion map texture. */
    get occlusionStrength(): number | undefined;
    set occlusionStrength(value: number | undefined);
    /** The emissive map texture. */
    get emissiveTexture(): Tiny.Texture | undefined;
    set emissiveTexture(value: Tiny.Texture | undefined);
    /** The alpha rendering mode of the material. */
    get alphaMode(): StandardMaterialAlphaMode;
    set alphaMode(value: StandardMaterialAlphaMode);
    /** The shadow casting light of the material. */
    get shadowCastingLight(): ShadowCastingLight | undefined;
    set shadowCastingLight(value: ShadowCastingLight | undefined);
    /** The debug rendering mode of the material. */
    get debugMode(): StandardMaterialDebugMode | undefined;
    set debugMode(value: StandardMaterialDebugMode | undefined);
    /**
     * Lighting environment used when rendering a mesh. If this value is not set,
     * the main lighting environment will be used by default.
     */
    get lightingEnvironment(): LightingEnvironment | undefined;
    set lightingEnvironment(value: LightingEnvironment | undefined);
    /**
     * Value indicating if the material is unlit. If this value if set to true,
     * all lighting is disabled and only the base color will be used.
     */
    get unlit(): boolean;
    set unlit(value: boolean);
    /**
     * 高光抗锯齿
    */
    get useSpecularAA(): boolean;
    set useSpecularAA(value: boolean);
    destroy(options: any): void;
    /**
     * Invalidates the shader so it can be rebuilt with the current features.
     */
    invalidateShader(): void;
    /**
     * Creates a standard material factory which can be used when loading models.
     * @param properties Properties to set on the material when created.
     */
    static factory(properties?: {}): {
        create: (source: unknown) => StandardMaterial;
    };
    /**
     * Creates a new standard material from the specified source.
     * @param source Source from which the material is created.
     */
    static create(source: unknown): StandardMaterial;
    render(mesh: Mesh3D, renderer: Tiny.Renderer): void;
    get isInstancingSupported(): boolean;
    createInstance(): InstancedStandardMaterial;
    createShader(mesh: Mesh3D, renderer: Tiny.Renderer): StandardShader;
    updateUniforms(mesh: Mesh3D, shader: Tiny.Shader): void;
}
