import * as Tiny from '@alipay/tiny.js';
import { MeshGeometry3D } from './geometry/mesh-geometry';
import { Mesh3D } from './mesh';
/**
 * Shader used specifically to render a mesh.
 */
export declare class MeshShader extends Tiny.Shader {
    /** Default state used to render a mesh. */
    state: Tiny.State & {
        culling: boolean;
        clockwiseFrontFace: boolean;
        depthTest: boolean;
    };
    /** Default draw mode used to render a mesh. */
    drawMode: Tiny.DRAW_MODES;
    /** The name of the mesh shader.
     * Used for figuring out if geometry attributes is compatible with the shader.
     *  This needs to be set to something different than default value when custom attributes is used.*/
    get name(): string;
    /**
     * Creates geometry with required attributes used by this shader. Override when using custom attributes.
     * @param geometry The geometry with mesh data.
     * @param instanced Value indicating if the geometry will be instanced.
     */
    createShaderGeometry(geometry: MeshGeometry3D, _instanced?: boolean): Tiny.Geometry;
    /**
     * Renders the geometry of the specified mesh.
     * @param mesh Mesh to render.
     * @param renderer Renderer to use.
     * @param state Rendering state to use.
     * @param drawMode Draw mode to use.
     */
    render(mesh: Mesh3D, renderer: Tiny.Renderer, state?: Tiny.State, drawMode?: Tiny.DRAW_MODES): void;
}
