import { glTFAsset } from './gltf/gltf-asset';
import { MaterialFactory } from './material/material-factory';
import { Mesh3D } from './mesh/mesh';
import { glTFAnimation } from './gltf/animation/gltf-animation';
import { Container3D } from './container';
import { InstancedModel } from './instanced-model';
import { Skin } from './skinning/skin';
import { Box3, Sphere } from '@tinyjs-plugin-three/math';
import { Light } from './lighting/light';
/**
 * Represents a model which includes a hierarchy of meshes and animations.
 */
export declare class Model extends Container3D {
    /** The animations included in the model. */
    animations: glTFAnimation[];
    /**
     * The meshes included in the model. Note that this array and the actual
     * childen are not automatically synchronized after the model has been loaded.
     */
    meshes: Mesh3D[];
    lights: Light[];
    instances: InstancedModel[];
    pickingInstance: InstancedModel;
    localBoundingBox?: Box3;
    localBoundingSphere?: Sphere;
    /**
     * All skin instances in the gltf are stored here!!!
     */
    skins: Skin[];
    /**
     * Creates a new model from a source.
     * @param source The source to create the model from.
     * @param materialFactory The factory to use for creating materials.
     */
    static from(source: glTFAsset, materialFactory?: MaterialFactory): Model;
    /**
     * Creates a new instance of this model.
     */
    createInstance(): InstancedModel;
    getSkinByName(inName: string): Skin;
    getAnimationByName(inName: string): glTFAnimation;
    getLocalBoundingBox(): Box3;
    /**
     * transform 到世界坐标系的 boundingBox
    */
    getWorldBoundingBox(): Box3;
    /**
     * local boundingSphere
    */
    getLocalBoundingSphere(): Sphere;
    /**
     * transform 到世界坐标系的 boundingSphere
    */
    getWorldBoundingSphere(): Sphere;
    private getRelativeTransform;
}
