import * as Tiny from '@alipay/tiny.js';
import { PickingHitArea } from './picking-hitarea';
/**
 * Manages the picking hit areas by keeping track on which hit areas needs to
 * be checked for interaction. Renders the hit area meshes to a texture which
 * is then used to map a mesh to a x/y coordinate. The picking manager is
 * registered as a renderer plugin.
 */
export declare class PickingManager {
    renderer: Tiny.Renderer;
    private _map;
    _hitAreas: PickingHitArea[];
    private _renderWhenTouchEnd;
    /**
     * Creates a new picking manager using the specified renderer.
     * @param renderer The renderer to use.
     */
    constructor(renderer: Tiny.Renderer);
    get renderWhenTouchEnd(): boolean;
    set renderWhenTouchEnd(value: boolean);
    private onPostRender;
    /**
     * Hit tests a area using the specified x/y coordinates.
     * @param x The x coordinate.
     * @param y The y coordinate.
     * @param hitArea The hit area to test.
     */
    containsHitArea(x: number, y: number, hitArea: PickingHitArea): boolean;
    destroy(): void;
}
