import * as Tiny from '@alipay/tiny.js';
import { DisplayObject } from '@alipay/tiny.js';
export interface PostProcessingSpriteOptions {
    /**
     * The width of the texture for the sprite.
     */
    width?: number;
    /**
     * The height of the texture for the sprite.
     */
    height?: number;
    /**
     * The object to render. When set, it will automatically be rendered to the
     * sprite's texture each frame.
     */
    objectToRender?: DisplayObject;
    /**
     * The resolution of the texture for the sprite.
     */
    resolution?: number;
    /**
     * texture 是否需要 resize 到全局？默认为 true
    */
    resizeToScreen?: boolean;
    /**
     * 是否将存储深度缓冲到存储到 depthTexture，默认为 false。如果为 true，则 multisample 参数不生效
    */
    addDepthTexture?: boolean;
    /**
     * MSAA 采样率，默认是 Tiny.MSAA_QUALITY.NONE (即不开启多重采样)
    */
    multisample?: Tiny.MSAA_QUALITY;
}
export declare class PostProcessingSprite extends Tiny.Sprite {
    renderer: Tiny.Renderer;
    private _renderTexture;
    private _tickerRenderFn?;
    private _preRenderFn?;
    /** The render texture. */
    get renderTexture(): Tiny.RenderTexture;
    /** The depth texture. */
    get depthTexture(): Tiny.BaseTexture<Tiny.Resource, Tiny.IAutoDetectOptions>;
    /**
     * Creates a new post processing sprite using the specified options.
     * @param renderer The renderer to use.
     * @param options The options for the render texture. If both width and height
     * has not been set, it will automatically be resized to the renderer size.
     */
    constructor(renderer: Tiny.Renderer, options?: PostProcessingSpriteOptions);
    renderObject(object: Tiny.DisplayObject): void;
    /**
     * Sets the resolution of the render texture.
     * @param resolution The resolution to set.
     */
    setResolution(resolution: number): void;
    destroy(options?: boolean | Tiny.IDestroyOptions): void;
}
