import * as Tiny from '@alipay/tiny.js';
import { MaterialRenderPass } from './material-render-pass';
import { Mesh3D } from '../mesh/mesh';
import { ShadowRenderPass } from '../shadow/shadow-render-pass';
import { PostProcessingSprite, PostProcessingSpriteOptions } from './post-processing-sprite';
import { Model } from '../model';
import { ShadowCastingLight } from '../shadow/shadow-casting-light';
import { RenderPass } from './render-pass';
/**
 * The standard pipeline renders meshes using the specified render passes. The
 * standard pipeline is created and used by default.
 */
export declare class StandardPipeline extends Tiny.ObjectRenderer {
    renderer: Tiny.Renderer;
    private _renderPasses;
    private _meshes;
    private _materialPass;
    private _shadowPass;
    /**
     * Returns the standard pipeline from the specified renderer.
     * @param renderer The renderer to use.
     */
    static from(renderer: Tiny.Renderer): StandardPipeline;
    /**
     * Creates a new standard pipeline using the specified renderer.
     * @param renderer The renderer to use.
     */
    constructor(renderer: Tiny.Renderer);
    private onPrerender;
    /**
     * Adds a render pass.
     * @param renderPass The pass to add.
     */
    addRenderPass<T extends RenderPass>(renderPass: T): T;
    /**
     * Removes a render pass.
     * @param renderPass The pass to remove.
     */
    removeRenderPass(renderPass: RenderPass): void;
    /**
     * Creates a new post processing sprite and uses that to render to it's
     * texture.
     * @param options The options when creating the sprite.
     */
    createPostProcessingSprite(options?: PostProcessingSpriteOptions): PostProcessingSprite;
    /**
     * Adds a mesh to be rendered.
     * @param mesh Mesh to add.
     */
    render(mesh: Mesh3D): void;
    /**
     * Renders the added meshes using the specified render passes.
     */
    flush(): void;
    /**
     * Sorts the meshes by rendering order.
     */
    sort(): void;
    /** The pass used for rendering shadows. */
    get shadowPass(): ShadowRenderPass;
    /** The pass used for rendering materials. */
    get materialPass(): MaterialRenderPass;
    /**
     * Enables shadows for the specified object. Adds the render pass to the
     * specified object and enables the standard material to use the casting light.
     * @param object The mesh or model to enable shadows for.
     * @param light The shadow casting light to associate with the
     * object when using the standard material.
     */
    enableShadows(object: Mesh3D | Model, light?: ShadowCastingLight): void;
    /**
     * Disables shadows for the specified object.
     * @param object The mesh or model to disable shadows for.
     */
    disableShadows(object: Mesh3D | Model): void;
    destroy(): void;
}
