import { Container3D } from '../container';
import { CubeMipmapTexture } from '../cubemap/cube-mipmap-texture';
import { Camera } from '../camera/camera';
/**
 * A skybox is a method of creating backgrounds in a 3D scene. It consists of
 * a cube texture which has six sides. Note that the skybox should be rendered
 * before all other objects in the scene.
 */
export declare class Skybox extends Container3D {
    private _mesh;
    /**
     * Creates a new skybox using the specified cube texture.
     * @param texture Cube texture to use for rendering.
     */
    constructor(texture: CubeMipmapTexture);
    /**
     * Camera used when rendering. If this value is not set, the main camera will
     * be used by default.
     */
    get camera(): Camera | undefined;
    set camera(value: Camera | undefined);
    /**
     * Cube texture used when rendering.
     */
    get texture(): CubeMipmapTexture;
    set texture(value: CubeMipmapTexture);
    /**
     * Creates a new skybox from the specified source.
     * @param source The source to create the skybox from. The format of the
     * source should be "cubemap_{{face}}.jpg". "{{face}}" will automatically be
     * replaced with the faces (posx, negx, posy, negy, posz, negz).
     */
    static from(source: string): Skybox;
}
