import { ObservablePoint3D } from './observable-point';
/**
 * Represents a rotation quaternion in 3D space.
 */
export declare class ObservableQuaternion extends ObservablePoint3D {
    _w: number;
    /**
     * Creates a new observable quaternion.
     * @param cb The callback when changed.
     * @param scope The owner of callback.
     * @param x The x component.
     * @param y The y component.
     * @param z The z component.
     * @param w The w component.
     */
    constructor(cb: () => void, scope: any, x?: number, y?: number, z?: number, w?: number);
    /**
     * Sets the euler angles in degrees.
     * @param x The x angle.
     * @param y The y angle.
     * @param z The z angle.
     */
    setEulerAngles(x: number, y: number, z: number): void;
    /** W component of the quaternion. */
    get w(): number;
    set w(value: number);
    /**
     * Creates a clone of this quaternion.
     * @param cb Callback when changed.
     * @param scope Owner of callback.
     */
    clone(cb?: (...params: any[]) => any, scope?: any): ObservableQuaternion;
    /**
     * Copies x, y, z, and w from the given quaternion.
     * @param p The quaternion to copy from.
     */
    copy(point: ObservableQuaternion): this;
    /**
     * Returns true if the given quaternion is equal to this quaternion.
     * @param p The quaternion to check.
     */
    equals(p: ObservableQuaternion): boolean;
    /**
     * Sets the quaternion to new x, y, z and w components.
     * @param x X component to set.
     * @param y Y component to set.
     * @param z Z component to set.
     * @param w W component to set.
     */
    set(x: number, y?: number, z?: number, w?: number): this;
}
