import * as Tiny from '@alipay/tiny.js';
import { ObservablePoint3D } from './observable-point';
import { ObservableQuaternion } from './observable-quaternion';
/**
 * Represents the matrix for a transform.
 */
export declare class TransformMatrix extends Tiny.Matrix {
    private _id;
    private _position?;
    private _scaling?;
    private _rotation?;
    private _up?;
    private _forward?;
    private _target?;
    array: Float32Array;
    /**
     * Creates a new transform matrix using the specified matrix array.
     * @param array The matrix array, expected length is 16. If empty, an identity
     * matrix is used as default.
     */
    constructor(array?: ArrayLike<number>);
    toArray(transpose: boolean, out?: Float32Array): Float32Array;
    /** Returns the current version id. */
    get id(): number;
    /** Returns the position component of the matrix. */
    get position(): Float32Array;
    /** Returns the scaling component of the matrix. */
    get scaling(): Float32Array;
    /** Returns the rotation quaternion of the matrix. */
    get rotation(): Float32Array;
    /** Returns the up vector of the matrix. */
    get up(): Float32Array;
    /** Returns the forward vector of the matrix. */
    get forward(): Float32Array;
    /** Returns the target (position + forward) vector of the matrix. */
    get target(): Float32Array;
    copyFrom(matrix: TransformMatrix): this;
    /**
     * Sets the rotation, position and scale components.
     * @param rotation The rotation to set.
     * @param position The position to set.
     * @param scaling The scale to set.
     */
    setFromRotationPositionScale(rotation: ObservableQuaternion, position: ObservablePoint3D, scaling: ObservablePoint3D): void;
    /**
     * Sets the multiplication result of world and local matrices.
     * @param world World transform matrix.
     * @param local Local transform matrix.
     */
    setFromMultiplyWorldLocal(world: TransformMatrix, local: TransformMatrix): void;
}
