import * as Tiny from '@alipay/tiny.js';
import { TransformMatrix } from './transform-matrix';
import { ObservablePoint3D } from './observable-point';
import { ObservableQuaternion } from './observable-quaternion';
/**
 * Handles position, scaling and rotation.
 */
export declare class Transform3D extends Tiny.Transform {
    /** The position in local space. */
    position: ObservablePoint3D;
    /** The scale in local space. */
    scale: ObservablePoint3D;
    /** The rotation in local space. */
    rotationQuaternion: ObservableQuaternion;
    /** The transformation matrix in world space. */
    worldTransform: TransformMatrix;
    /** The transformation matrix in local space. */
    localTransform: TransformMatrix;
    /** The inverse transformation matrix in world space. */
    inverseWorldTransform: TransformMatrix;
    /** The normal transformation matrix. */
    normalTransform: TransformMatrix;
    /**
     * Updates the local transformation matrix.
     */
    updateLocalTransform(): void;
    /**
     * Sets position, rotation and scale from an matrix array.
     * @param matrix The matrix to set.
     */
    setFromMatrix(matrix: TransformMatrix): void;
    /**
     * Updates the world transformation matrix.
     * @param parentTransform The parent transform.
     */
    updateTransform(parentTransform?: Tiny.Transform): void;
    /**
     * Rotates the transform so the forward vector points at specified point.
     * @param point The point to look at.
     * @param up The upward direction.
     */
    lookAt(point: number[], up?: number[]): void;
}
